==> v0.29.zip: leetcode-0.29/collections/easy.md <==
# 简单难度题目合集

这里的题目难度比较小， 大多是模拟题，或者是很容易看出解法的题目，另外简单题目一般使用暴力法都是可以解决的。 这个时候只有看一下数据范围，思考下你的算法复杂度就行了。

当然也不排除很多 hard 题目也可以暴力模拟，大家平时多注意数据范围即可。

以下是我列举的经典题目：

- [面试题 17.12. BiNode](../problems/binode-lcci.md)
- [0001. 两数之和](../problems/1.two-sum.md)
- [0020. 有效的括号](../problems/20.valid-parentheses.md)
- [0021. 合并两个有序链表](../problems/21.merge-two-sorted-lists.md)
- [0026. 删除排序数组中的重复项](../problems/26.remove-duplicates-from-sorted-array.md)
- [0053. 最大子序和](../problems/53.maximum-sum-subarray-cn.md)
- [0088. 合并两个有序数组](../problems/88.merge-sorted-array.md)
- [0101. 对称二叉树](../problems/101.symmetric-tree.md)
- [0104. 二叉树的最大深度](../problems/104.maximum-depth-of-binary-tree.md)
- [0108. 将有序数组转换为二叉搜索树](../problems/108.convert-sorted-array-to-binary-search-tree.md)
- [0121. 买卖股票的最佳时机](../problems/121.best-time-to-buy-and-sell-stock.md)
- [0122. 买卖股票的最佳时机 II](../problems/122.best-time-to-buy-and-sell-stock-ii.md)
- [0125. 验证回文串](../problems/125.valid-palindrome.md)
- [0136. 只出现一次的数字](../problems/136.single-number.md)
- [0155. 最小栈](../problems/155.min-stack.md)
- [0167. 两数之和 II 输入有序数组](../problems/167.two-sum-ii-input-array-is-sorted.md)
- [0169. 多数元素](../problems/169.majority-element.md)
- [0172. 阶乘后的零](../problems/172.factorial-trailing-zeroes.md)
- [0190. 颠倒二进制位](../problems/190.reverse-bits.md)
- [0191. 位1的个数](../problems/191.number-of-1-bits.md)
- [0198. 打家劫舍](../problems/198.house-robber.md)
- [0203. 移除链表元素](../problems/203.remove-linked-list-elements.md)
- [0206. 反转链表](../problems/206.reverse-linked-list.md)
- [0219. 存在重复元素 II](../problems/219.contains-duplicate-ii.md)
- [0226. 翻转二叉树](../problems/226.invert-binary-tree.md)
- [0232. 用栈实现队列](../problems/232.implement-queue-using-stacks.md)
- [0263. 丑数](../problems/263.ugly-number.md)
- [0283. 移动零](../problems/283.move-zeroes.md)
- [0342. 4的幂](../problems/342.power-of-four.md)
- [0349. 两个数组的交集](../problems/349.intersection-of-two-arrays.md)
- [0371. 两整数之和](../problems/371.sum-of-two-integers.md)
- [0437. 路径总和 III](../problems/437.path-sum-iii.md)
- [0455. 分发饼干](../problems/455.AssignCookies.md)
- [0575. 分糖果](../problems/575.distribute-candies.md)
- [0874. 模拟行走机器人](../problems/874.walking-robot-simulation.md)
- [1260. 二维网格迁移](../problems/1260.shift-2d-grid.md)
- [1332. 删除回文子序列](../problems/1332.remove-palindromic-subsequences.md)

==> v0.37.zip: leetcode-0.37/collections/easy.md <==
# 简单难度题目合集

这里的题目难度比较小， 大多是模拟题，或者是很容易看出解法的题目，另外简单题目一般使用暴力法都是可以解决的。 这个时候只有看一下数据范围，思考下你的算法复杂度就行了。

当然也不排除很多 hard 题目也可以暴力模拟，大家平时多注意数据范围即可。

以下是我列举的经典题目（带 91 字样的表示出自 **91 天学算法**活动）：

- [面试题 17.12. BiNode](../problems/binode-lcci.md)
- [0001. 两数之和](../problems/1.two-sum.md)
- [0020. 有效的括号](../problems/20.valid-parentheses.md)
- [0021. 合并两个有序链表](../problems/21.merge-two-sorted-lists.md)
- [0026. 删除排序数组中的重复项](../problems/26.remove-duplicates-from-sorted-array.md)
- [0053. 最大子序和](../problems/53.maximum-sum-subarray-cn.md)
- [0066. 加一](../problems/66.plus-one.md) 91
- [0088. 合并两个有序数组](../problems/88.merge-sorted-array.md)
- [0101. 对称二叉树](../problems/101.symmetric-tree.md)
- [0104. 二叉树的最大深度](../problems/104.maximum-depth-of-binary-tree.md)
- [0108. 将有序数组转换为二叉搜索树](../problems/108.convert-sorted-array-to-binary-search-tree.md)
- [0121. 买卖股票的最佳时机](../problems/121.best-time-to-buy-and-sell-stock.md)
- [0122. 买卖股票的最佳时机 II](../problems/122.best-time-to-buy-and-sell-stock-ii.md)
- [0125. 验证回文串](../problems/125.valid-palindrome.md)
- [0136. 只出现一次的数字](../problems/136.single-number.md)
- [0155. 最小栈](../problems/155.min-stack.md)
- [0160. 相交链表](../problems/160.Intersection-of-Two-Linked-Lists.md) 91
- [0167. 两数之和 II 输入有序数组](../problems/167.two-sum-ii-input-array-is-sorted.md)
- [0169. 多数元素](../problems/169.majority-element.md)
- [0172. 阶乘后的零](../problems/172.factorial-trailing-zeroes.md)
- [0190. 颠倒二进制位](../problems/190.reverse-bits.md)
- [0191. 位 1 的个数](../problems/191.number-of-1-bits.md)
- [0198. 打家劫舍](../problems/198.house-robber.md)
- [0203. 移除链表元素](../problems/203.remove-linked-list-elements.md)
- [0206. 反转链表](../problems/206.reverse-linked-list.md)
- [0219. 存在重复元素 II](../problems/219.contains-duplicate-ii.md)
- [0226. 翻转二叉树](../problems/226.invert-binary-tree.md)
- [0232. 用栈实现队列](../problems/232.implement-queue-using-stacks.md) 91
- [0263. 丑数](../problems/263.ugly-number.md)
- [0283. 移动零](../problems/283.move-zeroes.md)
- [0342. 4 的幂](../problems/342.power-of-four.md)
- [0349. 两个数组的交集](../problems/349.intersection-of-two-arrays.md)
- [0371. 两整数之和](../problems/371.sum-of-two-integers.md)
- [401. 二进制手表](../problems/401.binary-watch.md)
- [0437. 路径总和 III](../problems/437.path-sum-iii.md)
- [0455. 分发饼干](../problems/455.AssignCookies.md)
- [0575. 分糖果](../problems/575.distribute-candies.md)
- [821. 字符的最短距离](../problems/821.shortest-distance-to-a-character.md) 91
- [0874. 模拟行走机器人](../problems/874.walking-robot-simulation.md)
- [1260. 二维网格迁移](../problems/1260.shift-2d-grid.md)
- [1332. 删除回文子序列](../problems/1332.remove-palindromic-subsequences.md)
